#
# spec file for package piper
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2019 Matthias Bach <marix@marix.org>.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           piper
Version:        0.8
Release:        1.5
Summary:        Configuration UI for gaming mice
License:        GPL-2.0-only
Group:          Hardware/Other
URL:            https://github.com/libratbag/piper
Source0:        %{name}-%{version}.tar.xz
Source1:        README.SUSE
Patch1:         shebang-env.patch
Patch2:         use-python-3.6.patch
BuildRequires:  AppStream
BuildRequires:  fdupes
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  python3-cairo
BuildRequires:  python3-evdev
BuildRequires:  python3-flake8
BuildRequires:  python3-gobject-devel
BuildRequires:  python3-lxml
BuildRequires:  ratbagd >= 0.18
BuildRequires:  update-desktop-files
Requires:       python3-cairo
Requires:       python3-evdev
Requires:       python3-gobject
Requires:       python3-gobject-Gdk
Requires:       python3-lxml
Requires:       ratbagd >= 0.18
BuildArch:      noarch

%description
Piper is a GTK+ application to configure gaming mice. It is a graphical frontent
to the ratbagd DBUS daemon which provides the actual configuration support for the
devices to any user in the group "games".

%prep
%setup -q
%patch -P 1 -p1
%if 0%{?suse_version} <1550
%patch -P 2 -p1
%endif
cp %{SOURCE1} .

%build
PATH="${PATH}:%{_sbindir}" %meson
%meson_build

%check
%meson_test

%install
%meson_install
%fdupes %{buildroot}/%{_prefix}
%suse_update_desktop_file -r org.freedesktop.Piper Settings HardwareSettings
%find_lang %{name}

%files -f %{name}.lang
%license COPYING
%{_bindir}/piper
%{_datadir}/applications/org.freedesktop.Piper.desktop
%{_datadir}/icons/hicolor/scalable/apps/org.freedesktop.Piper.svg
%{_datadir}/icons/hicolor/symbolic/apps/org.freedesktop.Piper-symbolic.svg
%{_datadir}/metainfo/org.freedesktop.Piper.appdata.xml
%{_datadir}/piper
%{python3_sitelib}/piper
%{_mandir}/man1/piper.1%{?ext_man}
%doc README.SUSE

%changelog
* Thu Sep 26 2024 marix@marix.org
- Update to version 0.8:
  * Use new APIs from libratbag v0.18. Older libratbag versions are not
    supported.
  * Add debounce time and angle snapping changing.
  * Fix remapping of first two keys on keyboards only allowing to set left
    and right mouse buttons.
  * Reflect changes done with ratbagctl while Piper is running.
  * Add resolution disabling.
  * Add a text box for changing resolutions.
  * Use single-key actions for simple macros if possible (important for
    ASUS and some Logitech devices).
  * New images for following devices:
    + ASUS ROG Chakram X
    + ASUS ROG Gladius II Origin
    + ASUS ROG Gladius II Origin PNK LTD
    + ASUS ROG Harpe Wireless
    + ASUS ROG Keris Wireless
    + ASUS ROG Keris Wireless AimPoint
    + ASUS ROG Strix Carry
    + ASUS ROG Strix Impact II
    + ASUS ROG Strix Impact II Wireless
    + Glorious Model D
    + Glorious Model O/O-
    + Logitech G502 X Wireless
    + Logitech G502 X
    + Logitech G705
    + Logitech G Pro Keyboard
    + Logitech MX Anywhere 3B
    + Logitech MX Master 3S
- Switch osc service file to use manual instead of disabled which
  is no longer supported.
* Fri Mar  8 2024 Max Lin <mlin@suse.com>
- Add use-python-3.6.patch to hardcode python3.6 in meson.build for
  Leap 15 build
  * There are both python 3.11 and python 3.6 installed, python 3.11
    was selected, but it should use python 3.6 per the stat of the
    python module dependency
* Thu May 11 2023 Matthias Bach <marix@marix.org> - 0.7
- Document the need for users of Piper to be a member of the
  group games (bsc#1210669)
  * In the package description
  * In the new README.SUSE file
* Sun Jun 26 2022 marix@marix.org - 0.7
- Update to version 0.7:
  * New and improved devices:
  * Logitech G602
  * Logitech G903
  * Logitech MX Anywhere 2
  * Logitech MX Anywhere 3
  * Logitech MX Vertical
  * Mars Gaming MM4
  * SN TECH T3 Gaming Mouse
  * Added Ukrainian translation
  * Fix apply button activation on rates toggle
- Fix ratbagd dependency to properly require at least version 0.14
* Tue Jul 27 2021 marix@marix.org - 0.6
- Update to version 0.6:
  * Adds missing SVGs and device IDs for multiple devices.
* Thu Dec 24 2020 Matthias Bach <marix@marix.org> - 0.5
- Modernise spec file
* Mon Jun 22 2020 Matthias Bach <marix@marix.org>
- Update to version 0.5.1:
  * Add missing man page
  * Use SPDX 3 license identifiers in the code
* Sat Jun  6 2020 marix@marix.org
- Update to version 0.5:
  * New and Improved devices
    + Logitech MX Anywhere 2
    + Logitech G9x
    + Logitech G403 Hero
    + Logitech M720 Triathlon
    + Logitech G815
    + Logitech MX518
    + Logitech MX Master 3
  * Updated translations
    + Croattian
    + Brazilian Protuguese
    + French
    + Swedish
    + Dutch
    + Spanish
    + German
* Wed May 13 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Drop unneeded post(un) Requires update-desktop-files.
* Sat Feb 15 2020 marix@marix.org
- Update to version 0.4:
  * New and updated translations
  * Taiwanese Mandarin
  * Bulgarain
  * Italian
  * Polish
  * German
  * Croatian
  * Swedish
  * Brazilian Portuguese
  * More gracefully handle permission when connecting to the daemon
    [boo#1150413]
* Fri Aug  2 2019 marix@marix.org
- Update to version 0.3:
  * Switched back to "normal" version numbering
  * Check the APIVersion field in ratbagd to ensure it is
    compatible.
- Drop fix-resource-generation-script-shebang.patch as it has been
  applied upstream.
* Tue Apr 23 2019 Matthias Bach <marix@marix.org>
- Add missing dependency to python3-cairo. (boo#1132961)
* Sat Mar 30 2019 Matthias Bach <marix@marix.org>
- Update to version 0.2.904:
  * Adjusted to breaking DBus API changes of libratbag 0.9.905.
  * Removed "Add Profile" button as the functionality was not
    implemented.
  * SVG handling is now done wholly within Piper instead of relying
    on libratbag providing the SVGs.
- Added patch fix-resource-generation-script-shebang.patch which
  backports a fix for one of the build scripts.
* Wed Jan 30 2019 marix@marix.org
- Update to version 0.2.903:
  * Updated Polish and German translations.
  * Adjust to incompatible changes in ratbagd 0.9.904.
  * Improved handling of error cases.
  * Improved compatibility with HiDPI screens.
  * Provide localized desktop files
* Fri Oct 19 2018 marix@marix.org
- Added missing dependency to python3-gobject-Gdk.
* Thu Oct 18 2018 marix@marix.org
- Fixed use of deprecated syntax for BuildArch in the package
  spec.
* Wed Oct 17 2018 marix@marix.org
- Improved Category adjustment logic.
- Corrected Url in metadata to actually point to the upstream code
  repository.
- Replaced sed-patching by proper patch files.
- Minimised build dependencies.
* Tue Oct 16 2018 marix@marix.org
- Initial package creation
